@@ -16,6 +16,6 @@ if [ -d usr/share/glib-2.0/schemas ]; then
   /usr/bin/glib-compile-schemas /usr/share/glib-2.0/schemas >/dev/null 2>&1
 fi
 ( cd usr/lib64 ; rm -rf libgnome-bluetooth.so )
-( cd usr/lib64 ; ln -sf libgnome-bluetooth.so.13.0.1 libgnome-bluetooth.so )
+( cd usr/lib64 ; ln -sf libgnome-bluetooth.so.13 libgnome-bluetooth.so )
 ( cd usr/lib64 ; rm -rf libgnome-bluetooth.so.13 )
-( cd usr/lib64 ; ln -sf libgnome-bluetooth.so.13.0.1 libgnome-bluetooth.so.13 )
+( cd usr/lib64 ; ln -sf libgnome-bluetooth.so.13.1.0 libgnome-bluetooth.so.13 )
